@@ -4,7 +4,6 @@ use strict;
 use warnings;
 
 use Moose;
-use Net::SAML2::XML::Util qw/ no_comments /;
 
 
 use Net::SAML2::XML::Sig;
@@ -20,7 +19,7 @@ sub handle_response {
     my ($self, $response) = @_;
 
     # unpack and check the signature
-    my $xml = no_comments(decode_base64($response));
+    my $xml = decode_base64($response);
     my $xml_opts = { x509 => 1 };
     $xml_opts->{ cert_text } = $self->cert_text if ($self->cert_text);
     $xml_opts->{ exclusive } = 1;
@@ -58,7 +57,7 @@ Net::SAML2::Binding::POST
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
