@@ -15,11 +15,7 @@ has 'nameid_format' => (isa => NonEmptySimpleStr, is => 'ro', required => 1);
 sub new_from_xml {
     my ($class, %args) = @_;
 
-    my $dom = XML::LibXML->load_xml(
-                    string => no_comments($args{xml}),
-                    no_network => 1,
-                    load_ext_dtd => 0,
-                    expand_entities => 0 );
+    my $dom = no_comments($args{xml});
 
     my $xpath = XML::LibXML::XPathContext->new($dom);
     $xpath->registerNs('saml', 'urn:oasis:names:tc:SAML:2.0:assertion');
@@ -84,7 +80,7 @@ Net::SAML2::Protocol::LogoutRequest
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
