@@ -9,7 +9,7 @@ use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
 $DEBUG = 0;
 # Based on XML::Sig VERSION = '0.47';
-$VERSION = '0.36';
+$VERSION = '0.37';
 
 use base qw(Class::Accessor);
 Net::SAML2::XML::Sig->mk_accessors(qw(key));
@@ -23,6 +23,7 @@ use base qw/Exporter/;
 
 use Digest::SHA qw(sha1 sha224 sha256 sha384 sha512);
 use XML::LibXML;
+use Net::SAML2::XML::Util qw/ no_comments /;
 use MIME::Base64;
 use Carp;
 
@@ -111,7 +112,12 @@ sub sign {
 
     local $XML::LibXML::skipXMLDeclaration = $self->{ no_xml_declaration };
 
-    my $dom = XML::LibXML->load_xml( string => $xml );
+    my $dom = no_comments($xml);
+    #my $dom = XML::LibXML->load_xml(
+    #                string => $xml,
+    #                no_network => 1,
+    #                load_ext_dtd => 0,
+    #                expand_entities => 0 );
 
     $self->{ parser } = XML::LibXML::XPathContext->new($dom);
     $self->{ parser }->registerNs('dsig', 'http://www.w3.org/2000/09/xmldsig#');
@@ -253,7 +259,12 @@ sub verify {
     delete $self->{signer_cert};
     my ($xml) = @_;
 
-    my $dom = XML::LibXML->load_xml( string => $xml );
+    my $dom = no_comments($xml);
+    #my $dom = XML::LibXML->load_xml(
+    #                string => $xml,
+    #                no_network => 1,
+    #                load_ext_dtd => 0,
+    #                expand_entities => 0 );
 
     $self->{ parser } = XML::LibXML::XPathContext->new($dom);
     $self->{ parser }->registerNs('dsig', 'http://www.w3.org/2000/09/xmldsig#');
@@ -1478,7 +1489,7 @@ Net::SAML2::XML::Sig
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
